using Attribute;
using Model;
using Model.Base;
using Repository;
using Service;
using Microsoft.AspNetCore.Mvc;
using Vo.Admin;


namespace Services
{
    /// <summary>
    /// 入参表Service业务层处理
    /// </summary>
    [AppService(ServiceType = typeof(IPriProjectParamService), ServiceLifetime = LifeTime.Transient)]
    public class PriProjectParamService : BaseService<PriProjectParam>, IPriProjectParamService
    {
        /// <summary>
        /// 入参表-列表
        /// </summary>
        /// <param name="param">参数请求体</param>
        /// <param name="page">分页参数</param>
        /// <returns>列表</returns>
        public PagedInfo<GetPriProjectParamListVo> getPriProjectParamList([FromQuery] PagerInfo page, [FromQuery] PriProjectParam param)
        {
            //拼装查询条件
            var predicate = Expressionable.Create<PriProjectParam>();
            predicate = predicate.AndIF(!string.IsNullOrEmpty(param.fieldName), m => m.fieldName.Contains(param.fieldName));
            predicate = predicate.AndIF(!string.IsNullOrEmpty(param.fieldEnName), m => m.fieldEnName.Contains(param.fieldEnName));
            predicate = predicate.AndIF(param.projectId > 0, m => m.projectId == param.projectId);
            var response = Queryable()
                .Where(predicate.ToExpression())
                .OrderByDescending(m => m.id)
                .ToPage<PriProjectParam, GetPriProjectParamListVo>(page);
            return response;
        }



    }
}
