using Attribute;
using Model;
using Model.Base;
using Repository;
using Service;
using Microsoft.AspNetCore.Mvc;
using Vo.Admin;


namespace Services
{
    /// <summary>
    /// 递归停止条件对象表Service业务层处理
    /// </summary>
    [AppService(ServiceType = typeof(IPriRecursionEndTableService), ServiceLifetime = LifeTime.Transient)]
    public class PriRecursionEndTableService : BaseService<PriRecursionEndTable>, IPriRecursionEndTableService
    {
        /// <summary>
        /// 递归停止条件对象表-列表
        /// </summary>
        /// <param name="param">参数请求体</param>
        /// <param name="page">分页参数</param>
        /// <returns>列表</returns>
        public PagedInfo<GetPriRecursionEndTableListVo> getPriRecursionEndTableList([FromQuery] PagerInfo page, [FromQuery] PriRecursionEndTable param)
        {
            //拼装查询条件
            var predicate = Expressionable.Create<PriRecursionEndTable>();
            predicate = predicate.AndIF(param.projectId > 0, m => m.projectId == param.projectId);
            predicate = predicate.AndIF(!string.IsNullOrEmpty(param.tableEnName), m => m.tableEnName.Contains(param.tableEnName));
            var response = Queryable()
                .Where(predicate.ToExpression())
                .OrderByDescending(m => m.id)
                .ToPage<PriRecursionEndTable, GetPriRecursionEndTableListVo>(page);
            return response;
        }


        /// <summary>
        /// 递归停止条件对象表-下拉框数据
        /// </summary>
        /// <param name="page">分页参数</param>
        /// <returns>下拉框数据</returns>
        public PagedInfo<GetPriQueryTableDicVo> getPriQueryTableDic([FromQuery] PagerInfo page)
        {
            //拼装查询条件
            var predicate = Expressionable.Create<PriRecursionEndTable>();
            var response = Queryable()
                .Where(predicate.ToExpression())
                .OrderByDescending(m => m.id)
                .ToPage<PriRecursionEndTable, GetPriQueryTableDicVo>(page);
            return response;
        }



    }
}
