using Attribute;
using Model;
using Model.Base;
using Repository;
using Service;
using Microsoft.AspNetCore.Mvc;
using Vo.Admin;


namespace Services
{
    /// <summary>
    /// 条件返回字段Service业务层处理
    /// </summary>
    [AppService(ServiceType = typeof(IPriReturnFieldService), ServiceLifetime = LifeTime.Transient)]
    public class PriReturnFieldService : BaseService<PriReturnField>, IPriReturnFieldService
    {
        /// <summary>
        /// 条件返回字段-列表
        /// </summary>
        /// <param name="param">参数请求体</param>
        /// <param name="page">分页参数</param>
        /// <returns>列表</returns>
        public PagedInfo<GetPriReturnFieldListVo> getPriReturnFieldList([FromQuery] PagerInfo page, [FromQuery] PriReturnField param)
        {
            //拼装查询条件
            var predicate = Expressionable.Create<PriReturnField>();
            predicate = predicate.AndIF(!string.IsNullOrEmpty(param.fieldName), m => m.fieldName.Contains(param.fieldName));
            predicate = predicate.AndIF(!string.IsNullOrEmpty(param.fieldEnName), m => m.fieldEnName.Contains(param.fieldEnName));
            predicate = predicate.AndIF(param.queryTableId > 0, m => m.queryTableId == param.queryTableId);
            var response = Queryable()
                .Where(predicate.ToExpression())
                .OrderByDescending(m => m.id)
                .ToPage<PriReturnField, GetPriReturnFieldListVo>(page);
            return response;
        }



    }
}
